# @brightspace-ui-labs/s-html

Element wrapper of `.innerHTML` for data binding with HTML elements.

## Usage

### Example 1

Localize text with HTML elements using [app-localize-behavior](https://github.com/PolymerElements/app-localize-behavior).

locales.json
```json
{
"text": "<a href=\"/settings\">Settings</a>"
}
```

HTML
```html
<s-html html="[[localize('text')]]"></s-html>
```

### Example 2

Using `span` element for content styled with CSS.

locales.json
```json
{
"text": "<a class=\"red\" href=\"/settings\">Settings</a>"
}
```

CSS
```css
.red {
  color: red;
}
```

HTML
```html
<s-html html="[[localize('text')]]"><span></span></s-html>
```

### Example 3

Unescape escaped HTML elements.

locales.json
```json
{
"text": "polymer &lt;br&gt;"
}
```

HTML
```html
<s-html unescape html="[[localize('text')]]"></s-html>
```

## Installation

`npm i @brightspace-ui-labs/s-html`

## License

MIT: [StartPolymer/license](https://github.com/StartPolymer/license)

### Version Changes

All version changes should obey [semantic versioning](https://semver.org/) rules:
1. **MAJOR** version when you make incompatible API changes,
2. **MINOR** version when you add functionality in a backwards compatible manner, and
3. **PATCH** version when you make backwards compatible bug fixes.

The next version number will be determined from the commit messages since the previous release. Our semantic-release configuration uses the [Angular convention](https://github.com/conventional-changelog/conventional-changelog/tree/master/packages/conventional-changelog-angular) when analyzing commits:
* Commits which are prefixed with `fix:` or `perf:` will trigger a `patch` release. Example: `fix: validate input before using`
* Commits which are prefixed with `feat:` will trigger a `minor` release. Example: `feat: add toggle() method`
* To trigger a MAJOR release, include `BREAKING CHANGE:` with a space or two newlines in the footer of the commit message
* Other suggested prefixes which will **NOT** trigger a release: `build:`, `ci:`, `docs:`, `style:`, `refactor:` and `test:`. Example: `docs: adding README for new component`

To revert a change, add the `revert:` prefix to the original commit message. This will cause the reverted change to be omitted from the release notes. Example: `revert: fix: validate input before using`.

### Releases

When a release is triggered, it will:
* Update the version in `package.json`
* Tag the commit
* Create a GitHub release (including release notes)
* Deploy a new package to NPM
